@@ -8,7 +8,7 @@ function(x,...) UseMethod("information")
 information.lvm <- function(x,p,n,type=ifelse(model=="gaussian",
                                     c("E","hessian","varS","outer","sandwich","robust","num"),"outer"),
                             data,weight=NULL,
-                            data2=NULL,
+                            weight2=NULL,
                             model="gaussian",
                             method=lava.options()$Dmethod,
                             inverse=FALSE, pinv=TRUE,
@@ -27,7 +27,7 @@ information.lvm <- function(x,p,n,type=ifelse(model=="gaussian",
   }
   if (type[1]%in%c("num","hessian","obs")  | (type[1]%in%c("E","hessian") & model!="gaussian")) {
     require("numDeriv")
-    myf <- function(p0) score(x, p=p0, model=model,data=data, weight=weight,data2=data2,indiv=FALSE,n=n) ##...)
+    myf <- function(p0) score(x, p=p0, model=model,data=data, weight=weight,weight2=weight2,indiv=FALSE,n=n) ##...)
     ##    I <- -hessian(function(p0) logLik(x,p0,dd),p)
     I <- -jacobian(myf,p,method=method)
     res <- (I+t(I))/2 # Symmetric result
@@ -41,7 +41,7 @@ information.lvm <- function(x,p,n,type=ifelse(model=="gaussian",
     return(res)
   }
   if (type[1]=="varS" | type[1]=="outer") {
-    S <- score(x,p=p,data=na.omit(data),model=model,weight=weight,data2=data2,indiv=TRUE,...)
+    S <- score(x,p=p,data=na.omit(data),model=model,weight=weight,weight2=weight2,indiv=TRUE,...)
     ##    print("...")
     res <- t(S)%*%S
     if (inverse) {
@@ -139,7 +139,13 @@ information.lvm <- function(x,p,n,type=ifelse(model=="gaussian",
   {
     if (is.null(weight)) {
       ## information_Sigma <-  n/2*t(D$dS)%*%((iC)%x%(iC))%*%(D$dS)
-      information_Sigma <- n/2*t(D$dS)%*%kronprod(iC,iC,D$dS)
+        if (lava.options()$devel) {
+            information_Sigma <- matrix(0,length(p),length(p))
+            imean <- with(index(x)$parBelongsTo,mean)
+            information_Sigma[-imean,-imean] <- n/2*t(D$dS[,-imean])%*%kronprod(iC,iC,D$dS[,-imean])
+        } else {       
+            information_Sigma <- n/2*t(D$dS)%*%kronprod(iC,iC,D$dS)
+        }
     } else {
       ## information_Sigma <-  n/2*t(D$dS)%*%((iC)%x%(iC%*%W))%*%(D$dS)
       information_Sigma <- n/2*t(D$dS)%*%kronprod(iC,iC%*%W,D$dS)
@@ -157,16 +163,23 @@ information.lvm <- function(x,p,n,type=ifelse(model=="gaussian",
   }
 
   f <- function(p0) modelVar(x,p0)$xi
-  
-  idx <- with(index(x), (1:npar) + npar.mean)
-  dxi <- D$dxi; ##dxi[,idx] <- 0
+
+  ii <- index(x)
+  dxi <- D$dxi; 
   if (is.null(weight)) {
     information_mu <- n*t(D$dxi) %*% (iC) %*% (D$dxi)
   } else {
     information_mu <- n*t(D$dxi) %*% (iC%*%W) %*% (D$dxi)
   }
+
+  if (!(lava.options()$devel)) {
+      information <- information_Sigma+information_mu
+  } else {
+      mparidx <- with(ii$parBelongsTo,c(mean,reg))
+      information <- information_Sigma
+      information[mparidx,mparidx] <- information[mparidx,mparidx] + information_mu
+  }
   
-  information <- information_Sigma + information_mu
   if (inverse) {
     if (pinv)
       iI <- Inverse(information)
@@ -183,10 +196,10 @@ information.lvm <- function(x,p,n,type=ifelse(model=="gaussian",
 
 ##' @S3method information lvmfit
 information.lvmfit <- function(x,p=pars(x),n=x$data$n,data=model.frame(x),model=x$estimator,weight=Weight(x),
-                               data2=x$data$data2,
+                               weight2=x$data$weight2,
                                ...) {
   I <- information(x$model0,p=p,n=n,data=data,model=model,
-                   weight=weight,data2=data2,...)
+                   weight=weight,weight2=weight2,...)
   if (ncol(I)<length(p)) {
     I <- blockdiag(I,matrix(0,length(p)-ncol(I),length(p)-ncol(I)))
   }
