@@ -9,7 +9,7 @@
 "transform.lvm" <- function(`_data`,formula,fun,...) {
   y <- getoutcome(formula)
   xx <- attributes(y)$x
-  addvar(`_data`) <- c(y,xx)
+  addvar(`_data`) <- c(y)
   intercept(`_data`,y) <- 0; covariance(`_data`,y) <- 0
   if (is.null(attributes(`_data`)$transform))
     attributes(`_data`)$transform <- list()
